3 ms·
I ran some benchmarks and got about a 10% improvement by porting a simple function used in autorouting to C. With the subfunction ported to C, Bun was still ~15
by seveibar 2y ago
I ran some benchmarks and got about a 10% improvement by porting a simple function used in autorouting to C. With the subfunction ported to C, Bun was still ~15% slower than node (v8). As the article hints at, you probably need to port fairly large subfunctions to see major performance gains. Results:
Bun: 6.7410ms
Bun FFI w/ C: 6.0413ms
Node: 5.1307ms
C only: 4.3ms (+- 1ms)
I'm generally very bullish on Bun and was very happy with the DX for this C api. Great work to Jarred and the team!!!
benchmark code: https://github.com/tscircuit/bun-ffi-benchmarking https://github.com/tscircuit/bun-ffi-benchmarking